ChromosomeExplorer: The ChromosomeExplorer class
Description
Package: aroma.core
Class ChromosomeExplorerObject
~~|
~~+--Explorer
~~~~~~~|
~~~~~~~+--ChromosomeExplorer
Directly known subclasses:
public static class ChromosomeExplorer
extends Explorer
Usage
ChromosomeExplorer(model=NULL, zooms=2^(0:6), ...)
Arguments
zooms
An positive integer vector specifying for which zoom
levels the graphics should be generated. Fields and Methods
Methods:
|
|
display |
| - |
|
getChromosomes |
Gets the chromosomes available. |
|
|
getFullNames |
| - |
|
getModel |
Gets the model. |
|
|
getNames |
| - |
|
getPath |
- |
|
|
getZooms |
| - |
|
indexOf |
- |
|
|
process |
| Generates image files, scripts and dynamic pages for the explorer. |
|
setArrays |
Sets the arrays. |
|
|
setCytoband |
| - |
|
setZooms |
- |
Methods inherited from Explorer:
addIncludes, addIndexFile, as.character, display, getAlias, getArraysOfInput, getAsteriskTags, getFullName, getIncludePath, getMainPath, getName, getNameOfInput, getNames, getPath, getReportPathPattern, getRootPath, getSampleLayerPrefix, getSubname, getTags, getTagsOfInput, getTemplatePath, getVersion, nbrOfArrays, process, setAlias, setArrays, setReportPathPattern, setSubname, setup, splitByReportPathPattern, updateSetupExplorerFile Methods inherited from Object:
$, $<-, [[, [[<-, as.character, attach, attachLocally, clearCache, clearLookupCache, clone, detach, equals, extend, finalize, getEnvironment, getFieldModifier, getFieldModifiers, getFields, getInstantiationTime, getStaticInstance, hasField, hashCode, ll, load, objectSize, print, save, asThis Generating PNG images
In order to get better looking graphs, but also to be able to generate
bitmap images on systems without direct bitmap support, which is the case
when running R in batch mode or on Unix without X11 support, images are
created using the png2 device (a wrapper for
bitmap() immitating png()). The png() is only
used if png2(), which requires Ghostscript, does not.
Note, when images are created using png2(), the images does
not appear immediately, although the function call is completed,
so be patient.