This package is a support package for aroma.affymetrix. This package should be considered to be in an alpha or beta phase. You should expect the API to be changing over time. For practical purposes, consider this package a private package.
install.packages("aroma.core").