Download a particular chip type annotation file by its chip type, tags and suffix.
# S3 method for AromaRepository
downloadChipTypeFile(this, chipType, tags=NULL, suffix=sprintf(".%s", ext), ext=NULL,
..., gunzip=TRUE, skip=TRUE, overwrite=FALSE, mustExist=TRUE, verbose=getVerbose(this))Returns the relative pathname of the uncompressed downloaded file.
The chip type of the file to be downloaded.
Optional tags of the file to be downloaded.
The filename suffix (including any preceding period) of the file to be downloaded.
The filename extension.
Additional arguments passed to *downloadFile().
If TRUE, an already downloaded file is skipped.
If TRUE, an not skipping, an already downloaded file
is overwritten, otherwise an error is thrown.
If TRUE, an exception is thrown if no file matching
is available either locally or on the repository.
See Verbose.
Henrik Bengtsson
For more information see AromaRepository.