Learn R Programming

aroma.core (version 3.3.2)

getTags.AromaTransform: Gets the tags of the output data set

Description

Gets the tags of the output data set, which equals the tags of the input data set plus the tags of this transformation.

Usage

# S3 method for AromaTransform
getTags(this, collapse=NULL, ...)

Value

Returns a character

vector.

Arguments

...

Not used.

Author

Henrik Bengtsson

See Also

For more information see AromaTransform.