Learn R Programming

aroma.core (version 3.0.0)

isDone.AromaTransform: Checks if the data set is processed or not

Description

Checks if the data set is processed or not.

Usage

"isDone"(this, ...)

Arguments

...
Arguments passed to *findFilesTodo().

Value

Returns TRUE if the data set is processed, otherwise FALSE.

See Also

For more information see AromaTransform.