Learn R Programming

aroma.core (version 3.3.0)

setArrays.Explorer: Sets the arrays

Description

Sets the arrays to be processed by the explorer.

Usage

# S3 method for Explorer
setArrays(...)

Value

Returns a character

vector.

Arguments

arrays

A character (or integer) vector of arrays to be considered. If NULL, all arrays of the data set are considered.

...

Not used.

Author

Henrik Bengtsson

See Also

For more information see Explorer.