powered by
Gets the tags of the output data set, which equals the tags of the input data set plus the tags of this transformation.
# S3 method for AromaTransform getTags(this, collapse=NULL, ...)
Returns a character
character
vector.
vector
Not used.
Henrik Bengtsson
For more information see AromaTransform.
AromaTransform